/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.web.utils;

import org.wso2.registry.web.beans.AdminBean;
import org.wso2.registry.web.UIConstants;
import org.wso2.registry.config.RegistryConfiguration;
import org.wso2.registry.config.DataBaseConfiguration;
import org.wso2.registry.RegistryConstants;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.ServletException;
import java.util.Map;
import java.io.IOException;

public class AdminUtil {

    public static AdminBean getAdminBean(HttpServletRequest request) {

        RegistryConfiguration regConfiguration = (RegistryConfiguration) request.getSession().
                getServletContext().getAttribute(RegistryConstants.REGISTRY_CONFIG);

        Map dbConfigs = regConfiguration.getDbconfgigMap();

        AdminBean adminBean = new AdminBean();
        adminBean.setDbConfigs(dbConfigs);
        return adminBean;
    }

    public static void addDBURLBasedConfiguration(HttpServletRequest request, HttpServletResponse response) {

        RegistryConfiguration regConfiguration = (RegistryConfiguration) request.getSession().
                getServletContext().getAttribute(RegistryConstants.REGISTRY_CONFIG);

        String configName = request.getParameter("configName");
        String dbURL = request.getParameter("dbURL");
        String driverName = request.getParameter("driverName");
        String userName = request.getParameter("userName");
        String password = request.getParameter("password");

        DataBaseConfiguration dbConfiguration = new DataBaseConfiguration();
        dbConfiguration.setConfigName(configName);
        dbConfiguration.setDbUrl(dbURL);
        dbConfiguration.setDriverName(driverName);
        dbConfiguration.setUserName(userName);
        dbConfiguration.setPassWord(password);

        regConfiguration.addDataBaseConfiguration(dbConfiguration);

        try {
            request.getRequestDispatcher(UIConstants.ADMIN_JSP).forward(request, response);
        } catch (ServletException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public static void removeDBConfiguration(HttpServletRequest request, HttpServletResponse response) {

        RegistryConfiguration regConfiguration = (RegistryConfiguration) request.getSession().
                getServletContext().getAttribute(RegistryConstants.REGISTRY_CONFIG);

        regConfiguration.removeDataBaseConfiguration(request.getParameter("config"));

        try {
            request.getRequestDispatcher(UIConstants.ADMIN_JSP).forward(request, response);
        } catch (ServletException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public static void applyDBConfiguration(HttpServletRequest request, HttpServletResponse response) {

        RegistryConfiguration regConfiguration = (RegistryConfiguration) request.getSession().
                getServletContext().getAttribute(RegistryConstants.REGISTRY_CONFIG);

        DataBaseConfiguration dataBaseConfiguration =
                regConfiguration.getDataBaseConfiguration(request.getParameter("config"));
        regConfiguration.setDeafultDataBaseConfiguration(dataBaseConfiguration);

        try {
            request.getRequestDispatcher(UIConstants.ADMIN_JSP).forward(request, response);
        } catch (ServletException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
}
