/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.web.utils;

import org.wso2.registry.secure.SecureRegistry;
import org.wso2.registry.RegistryException;
import org.wso2.registry.Tag;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.ServletException;
import java.io.PrintWriter;
import java.io.IOException;

public class TagUtil {

    public static void tag(HttpServletRequest request, HttpServletResponse response) {

        try {
            TagUtil.applyTag(request);
        } catch (RegistryException e) {
            try {
                TagUtil.sendTagCloud(request, response, e.getMessage());
            } catch (RegistryException e1) {
                try {
                    TagUtil.sendPlainTagError(response, e.getMessage() + " | " + e1.getMessage());
                } catch (RegistryException ignore) {}
            }
        }

        try {
            TagUtil.sendTagCloud(request, response, null);
        } catch (RegistryException e) {
            try {
                TagUtil.sendPlainTagError(response, e.getMessage());
            } catch (RegistryException ignore) {}
        }
    }

    public static void applyTag(HttpServletRequest request) throws RegistryException {

        SecureRegistry secureRegistry = CommonUtil.getUserRegistry(request);

        String resourcePath = request.getParameter("resourcePath");
        String tag = request.getParameter("tag");

        secureRegistry.applyTag(resourcePath, tag);
    }

    public static void sendTagCloud(HttpServletRequest request, HttpServletResponse response, String message)
            throws RegistryException {

        SecureRegistry secureRegistry = CommonUtil.getUserRegistry(request);
        response.setContentType("text/html");
        PrintWriter out = null;
        try {
            out = response.getWriter();
        } catch (IOException e) {
            throw new RegistryException(e.getMessage());
        }

        String resourcePath = request.getParameter("resourcePath");
        Tag[] tags = secureRegistry.getTags(resourcePath);

        if (message != null && message.length() > 0) {
            out.println(message + "<br/>");
        }

        for (int i = 0; i < tags.length; i++) {
            Tag tag = tags[i];
            out.println("<a href='/wso2registry/system/search?criteria=" + tag.getTagName() + " class='cloud-x" + tag.getCategary() + ">" + tag.getTagName() + "</a>");
        }

        out.flush();
        out.close();
    }

    public static void sendPlainTagError(HttpServletResponse response, String message) throws RegistryException {

        response.setContentType("text/html");
        PrintWriter out = null;
        try {
            out = response.getWriter();
        } catch (IOException e) {
            throw new RegistryException(e.getMessage());
        }

        if (message == null || message.length() == 0) {
            message = "Error occured while perfoming the tagging.";
        }

        out.println(message);

        out.flush();
        out.close();
    }
}
